"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.watchFeedSaga = watchFeedSaga;

var _effects = require("redux-saga/effects");

var _api = _interopRequireDefault(require("../../../api"));

var _actions = _interopRequireDefault(require("../../actions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function* getTopFeed() {
  try {
    yield (0, _effects.put)(_actions.default.getTopFeed.reset());
    const {
      data
    } = yield (0, _effects.call)(_api.default.topFeed.getTopFeed);
    const payload = {
      data
    };
    yield (0, _effects.put)(_actions.default.getTopFeed.success(payload));
  } catch (error) {
    yield (0, _effects.put)(_actions.default.getTopFeed.failure(error));
  }
}

function* getNestedComments(newData) {
  if (newData && newData.length > 0) {
    yield getKids(newData);
  }
}

const getYields = action => {
  const allYields = action.payload.map(item => {
    return (0, _effects.call)(_api.default.feed.getFeed, item);
  });
  return allYields;
};

const getData = data => {
  const newData = data.map(item => {
    if (item && item.data && item.data.id) {
      const obj = {
        id: item.data.id,
        feed: item.data
      };
      return obj;
    }
  });
  return newData;
};

function* getFeed(action) {
  try {
    const allYields = getYields(action);
    const [...data] = yield (0, _effects.all)(allYields);
    const newData = getData(data);
    yield getNestedComments(newData);
    const {
      topFeed
    } = yield (0, _effects.select)(state => state);
    const fullData = [...topFeed.fullData, ...newData];
    const payload = {
      fullData
    };
    yield (0, _effects.put)(_actions.default.getFeed.success(payload));
  } catch (error) {
    yield (0, _effects.put)(_actions.default.getFeed.failure(error));
  }
}

function* getKidsFeed(action) {
  try {
    const allYields = getYields(action);
    const [...data] = yield (0, _effects.all)(allYields);
    const newData = getData(data);
    yield getNestedComments(newData);
    const feedObj = {};
    newData.forEach(element => {
      if (element && element.feed) {
        feedObj[element.id] = element.feed;
      }
    });
    yield (0, _effects.put)(_actions.default.getKidsFeed.success(feedObj));
  } catch (error) {
    yield (0, _effects.put)(_actions.default.getKidsFeed.failure(error));
  }
}

function* getKids(newData) {
  const listArr = [];
  newData.forEach(item => {
    item.feed.kids && listArr.push(item.feed.kids);
  });
  let merged = [].concat.apply([], listArr);
  yield (0, _effects.put)(_actions.default.getKidsFeed.request(merged));
}

function* watchFeedSaga() {
  yield (0, _effects.takeLatest)(_actions.default.getTopFeed.request, getTopFeed);
  yield (0, _effects.takeEvery)(_actions.default.getFeed.request, getFeed);
  yield (0, _effects.takeEvery)(_actions.default.getKidsFeed.request, getKidsFeed);
}
//# sourceMappingURL=index.js.map